@@ -80,6 +80,7 @@ class TestAP(unittest.TestCase):
         self.loop = asyncio.new_event_loop() # needed to initialize asyncio
         self.reg = NetworkElementRegistry(self.ctx, {}, Ap)
         self.reg.ne_type = 'ap'
+        self.ctx.company_uuid = UUID('4a24ad99-d502-3846-a8de-6c202c665a37')
         asyncio.set_event_loop(self.loop)
         self._await(self.ctx.start())
 
@@ -171,14 +172,14 @@ class TestAP(unittest.TestCase):
         msg.data.uptime = 1000
         wlan = msg.data.interfaces.add()
         link, radio = wlan.links.add(), wlan.radios.add()
-        link.mac_address = "08:55:31:0a:d4:38"
         link.in_octets = 402579957
         link.out_octets = 505139803
+        link.poller_hash = b'\x01'
         stream = radio.streams.add()
         wlink = stream.links.add()
-        wlink.mac_address = "08:55:31:0a:d4:38"
         wlink.tx_link_rate = 2310000000
         wlink.rx_link_rate = 2810000000
+        wlink.poller_hash = b'\x01'
 
         total_tx_airtime = 0
         total_rx_airtime = 0
